@@ -20,7 +20,7 @@
 //! ```
 
 #![deny(unsafe_code)]
-#![cfg_attr(not(feature = "std"), not(test), no_std)]
+#![cfg_attr(all(not(feature = "std"), not(test)), no_std)]
 
 #[cfg(not(feature = "std"))]
 extern crate alloc;
